pitchtools.NumberedPitchClassColorMap
=====================================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap

.. autoclass:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.colors
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.get
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.is_twelve_tone_complete
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.is_twenty_four_tone_complete
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.pairs
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.pitch_iterables
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__eq__
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__format__
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__getitem__
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__ne__
      ~abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.colors
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.is_twelve_tone_complete
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.is_twenty_four_tone_complete
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.pairs
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.pitch_iterables
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.get
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassColorMap.NumberedPitchClassColorMap.__repr__
   :noindex:
